@@ -29,7 +29,7 @@
 __all__ = ["BadLines", "Checker" ,"InvalidPath", "Len8Error"]
 
 __productname__ = "len8"
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 __description__ = "A utility for keeping line lengths within PEP 8 standards."
 __url__ = "https://github.com/parafoxia/len8"
 __docs__ = "https://len8.readthedocs.io/en/latest/"
@@ -38,5 +38,5 @@ __license__ = "BSD-3-Clause"
 __bugtracker__ = "https://github.com/parafoxia/len8/issues"
 __ci__ = "https://github.com/parafoxia/len8/actions"
 
+from .checker import Checker
 from .errors import *
-from .models import Checker
