@@ -26,27 +26,7 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-import sys
-
-from len8.errors import BadLines, InvalidPath
-from len8.models import Checker, Parser
-
-
-def main() -> None:
-    parser = Parser()
-    checker = Checker(
-        exclude=parser.exclude,
-        extend=parser.extend,
-        strict=True,
-    )
-
-    try:
-        checker.check(*parser.paths)
-
-    except (BadLines, InvalidPath) as e:
-        print(e)
-        sys.exit(1)
-
+from len8 import cli
 
 if __name__ == "__main__":
-    main()
+    cli.len8()
